/// <reference types="node" />
import { Server } from 'http';
import * as express from 'express';
export declare class MockServer {
    private handler;
    private server;
    private hostname;
    private port;
    private routes;
    /**
     * The constructor of the Mock Server
     * @param parameters The parameters of the mock server
     * @param parameters.hostname Optional. The hostname of the server, default is localhost
     * @param parameters.port Optional. The port the server listens to, default is 3000
     * @param parameters.routes Required. An array of the routes the server will mock
     * @param parameters.routes.method Required. The request method, for example: get
     * @param parameters.routes.path Required. The path of the url, for example: /user
     * @param parameters.routes.statusCode Optional. The status code of the response
     * @param parameters.routes.headers Optional. The response headers
     * @param parameters.routes.response Required. The response body, for example: { id: 1 }
     */
    constructor(parameters: ServerParameters);
    /**
     * Starting the mock server
     */
    start(): void;
    /**
     * Handling the response
     * @param request The request object
     * @param response The response object
     * @param route The route object
     */
    private handleResponse;
    /**
     * Stopping the mock server
     */
    stop(): void;
    /**
     * Returning the mock server object
     */
    getServer(): Server | undefined;
}
/**
 * The parameters of the mock server that are passed over in the constructor
 * @param hostname Optional. The hostname of the server, default is localhost
 * @param port Optional. The port the server listens to, default is 3000
 * @param routes Required. An array of the routes the server will mock / A string of the json file path.
 */
export declare type ServerParameters = {
    hostname?: string;
    port?: number;
    routes: Route[] | string;
};
/**
 * A type for each route defined and passed over to the mock server.
 * @param method Required. The request method, for example: get
 * @param path Required. The path of the url, for example: /user
 * @param statusCode Optional. The status code of the response
 * @param headers Optional. The response headers
 * @param response Required. The response body, for example: { id: 1 }
 */
export declare type Route = {
    method: RequestMethod;
    path: string;
    statusCode?: number;
    headers?: {
        [key: string]: any;
    };
    response: {
        [key: string]: any;
    } | ResponseFunction;
};
/**
 * Available request methods
 */
declare type RequestMethod = 'get' | 'post' | 'put' | 'delete' | 'patch' | 'options' | 'head';
/**
 * A generic flexible function for function response handling
 */
declare type ResponseFunction = (request: Request, response: Response) => void;
/**
 * The request object
 */
export declare type Request = express.Request;
/**
 * The response object
 */
export declare type Response = express.Response;
export {};
